@@ -29,7 +29,7 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Use inline C code.
 use Inline 'C';
@@ -95,7 +95,7 @@ my %termhash = (
     "xiterm+thai"            => "xiterm+thai",             # successful tested
     "xterm"                  => "XTerm",                   # successful tested
     "xvt"                    => "xvt",                     # know, but not tested
-    "yakuake"                => "Yakuake"                 # successful tested
+    "yakuake"                => "Yakuake"                  # successful tested
 );
 
 #------------------------------------------------------------------------------#
@@ -173,14 +173,17 @@ sub login_users {
 #                                                                              #
 # Description:                                                                 #
 # Read the content of the file /etc/shells and store the content in a string   #
-# variable. Then the content is splited up into lines. In a loop the lines are #
-# used where a valid login shell is given. Then the path is removed from the   #
-# line with the login shell. The login shell is added to an array. In a last   #
-# step douple entries are removed from the array.                              #
+# variable. Then the content is splited up into lines. In a loop the lines     #
+# are used where a valid login shell is given. Then the path is removed from   #
+# the line with the login shell. The login shell is added to an array. In a    #
+# last step douple entries are removed from the array.                         #
+#                                                                              #
+# @argument: None                                                              #
+# @return:   @login_shells  array with valid login shells  (array)             #
 #------------------------------------------------------------------------------# 
 sub login_shells {
-    # Declare the login shell array.
-    my @login_array;
+    # Declare the login shells array.
+    my @login_shells;
     # Set the file for reading.
     my $file = "/etc/shells";
     # Read the content from the file.
@@ -194,14 +197,14 @@ sub login_shells {
             # Remove the path from the line with the login shell.
             my ($shell) = $line =~ /^\/.*\/(.*)$/;
             # Add the login shell to the array.
-            push(@login_array, $shell);
+            push(@login_shells, $shell);
         };
     };
-    # Remove double entries from the array.
-    my %hash = map {$_, 1} @login_array;
-    @login_array = keys %hash;
+    # Remove the double entries from the array.
+    my %login_hash = map({$_, 1} @login_shells);
+    @login_shells = keys %login_hash;
     # Return the array with the login shells.
-    return @login_array;
+    return @login_shells;
 };
 
 #------------------------------------------------------------------------------# 
@@ -366,7 +369,7 @@ sub whichterminalami {
     # Get the output flag from the subroutine argument.
     my $flag = (defined $_[0] ? $_[0] : '');
     # Set the string variable.
-    my $errstr = "Unknown Terminal";
+    my $str = "Unknown Terminal";
     # Declace the terminal output variables.
     my $terminal;
     my $terminal_ftn;
@@ -405,13 +408,13 @@ sub whichterminalami {
     };
     # Return terminal string based on flag setting.
     if ($flag eq "PROC") {
-        $terminal = (defined $terminal_process ? $terminal_process : $errstr);
+        $terminal = (defined $terminal_process ? $terminal_process : $str);
     } elsif ($flag eq "PATH") {
-        $terminal = (defined $terminal_path ? $terminal_path : $errstr);
+        $terminal = (defined $terminal_path ? $terminal_path : $str);
     } elsif ($flag eq "FTN") {
-        $terminal = (defined $terminal_ftn ? $terminal_ftn : $errstr);
+        $terminal = (defined $terminal_ftn ? $terminal_ftn : $str);
     } else {
-        $terminal = (defined $terminal_name ? $terminal_name : $errstr);
+        $terminal = (defined $terminal_name ? $terminal_name : $str);
     };
     # Return the identified terminal string.
     return $terminal;
@@ -442,7 +445,6 @@ __END__
 =head1 NAME
 
 Terminal::Identify - Perl extension for identifying the terminal emulator
-which is in use by the logged-in user
 
 =head1 SYNOPSIS
 
@@ -509,19 +511,20 @@ to detect that a system console is being used by a logged-in user.
   # Declare the terminal variable.
   my $terminal;
 
+  # Subroutine call without argument.
   $terminal = whichterminalami();
   print $terminal . "\n";
 
-  $term = whichterminalami("PROC");
+  # Subroutine call with argument "PROC".
+  $terminal = whichterminalami("PROC");
   print $terminal . "\n";
 
-  $term = whichterminalami("PATH"); 
+  # Subroutine call with argument "PATH".
+  $terminal = whichterminalami("PATH"); 
   print $terminal . "\n";
 
-  $term = whichterminalami("FTN");
-  print $terminal . "\n";
-
-  $term = whichterminalami();
+  # Subroutine call with argument "FTN".
+  $terminal = whichterminalami("FTN");
   print $terminal . "\n";
 
 =head1 VARIABLES EXPLANATION
